#

##

##

##

    	controls
    		# help
    		# navigation
    		# moves
    		# accessibility
    		# guide
    		# primer
    		# instructions
    		# directions

    	bionic eyes
    		VANI - Vivani Medical, Inc.

    	speech synthesis
    		talk to browser?
    			https://developer.mozilla.org/en-US/docs/Web/API/Web_Speech_API/Using_the_Web_Speech_API

    		synthesis:

    	OS

    		Linux:
    			Orca:
    				start:

    		Windows:
    			Narrator:

    		Apple:
    			Screen Reader: